.. _how_to_install:

Installing feinsum
==================

From pypi:

.. code-block::

    pip install feinsum


From source:

.. code-block::

    git clone https://github.com/kaushikcfd/feinsum
    cd feinsum
    pip install -e .
